==> ezpublish-4.0.0.tgz: ezpublish/extension/ezodf/translations/untranslated/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose document placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export eZ publish content to OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can export any eZ publish content object to an OpenOffice.org Writer document format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>The object was imported as: %class_name</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>Document imported as</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>The images are placed in the media and can be re-used.</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>Import another document</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>Import OpenOffice.org document</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>Replace document</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>Import to</source>
        <translation type="unfinished"></translation>
    </message>
     <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ publish from this page. You are
asked where to place the document and eZ publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch node with id  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ezpublish-4.1.3p1.tgz: ezpublish/extension/ezodf/translations/untranslated/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Upload file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export eZ Publish content to OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can export any eZ Publish content object to an OpenOffice.org Writer document format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The images are placed in the media library and can be re-used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ Publish from this page. You are
asked where to place the document and eZ Publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch node with id </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
